@@ -121,6 +121,7 @@ draw_dendrogram = function(hc, horizontal = T){
 	else{
 		gr = rectGrob()
 		pushViewport(viewport(height = unit(1, "grobwidth", gr), width = unit(1, "grobheight", gr), angle = 90))
+		dist[, 1] = 1 - dist[, 1] 
 		for(i in 1:nrow(m)){
 			draw_connection(dist[m[i, 1], 1], dist[m[i, 2], 1], dist[m[i, 1], 2], dist[m[i, 2], 2], h[i])
 		}
@@ -551,50 +552,51 @@ kmeans_pheatmap = function(mat, k = min(nrow(mat), 150), sd_limit = NA, ...){
 #' @author  Raivo Kolde <rkolde@@gmail.com>
 #' @examples
 #'  # Generate some data
-#'	test = matrix(rnorm(200), 20, 10)
-#'	test[1:10, seq(1, 10, 2)] = test[1:10, seq(1, 10, 2)] + 3
-#'	test[11:20, seq(2, 10, 2)] = test[11:20, seq(2, 10, 2)] + 2
-#'	colnames(test) = paste("Test", 1:10, sep = "")
-#'	rownames(test) = paste("Gene", 1:20, sep = "")
-#'
-#'	# Draw heatmaps
-#'	pheatmap(test)
-#'	pheatmap(test, kmeans_k = 2)
-#'	pheatmap(test, scale = "row", clustering_distance_rows = "correlation")
-#'	pheatmap(test, color = colorRampPalette(c("navy", "white", "firebrick3"))(50))
-#'	pheatmap(test, cluster_row = FALSE)
-#'	pheatmap(test, legend = FALSE)
-#'	pheatmap(test, display_numbers = TRUE)
-#'	pheatmap(test, display_numbers = TRUE, number_format = "%.1e")
-#'	pheatmap(test, cluster_row = FALSE, legend_breaks = -1:4, legend_labels = c("0", 
-#' "1e-4", "1e-3", "1e-2", "1e-1", "1"))
-#'	pheatmap(test, cellwidth = 15, cellheight = 12, main = "Example heatmap")
-#'	pheatmap(test, cellwidth = 15, cellheight = 12, fontsize = 8, filename = "test.pdf")
-#'
-#'
-#'	# Generate column annotations
-#'	annotation = data.frame(Var1 = factor(1:10 \%\% 2 == 0, labels = c("Class1", "Class2")), Var2 = 1:10)
-#'	annotation$Var1 = factor(annotation$Var1, levels = c("Class1", "Class2", "Class3"))
-#'	rownames(annotation) = paste("Test", 1:10, sep = "")
-#'
-#'	pheatmap(test, annotation = annotation)
-#'	pheatmap(test, annotation = annotation, annotation_legend = FALSE)
-#'	pheatmap(test, annotation = annotation, annotation_legend = FALSE, drop_levels = FALSE)
-#'
-#'	# Specify colors
-#'	Var1 = c("navy", "darkgreen")
-#'	names(Var1) = c("Class1", "Class2")
-#'	Var2 = c("lightgreen", "navy")
-#'
-#'	ann_colors = list(Var1 = Var1, Var2 = Var2)
-#'
-#'	pheatmap(test, annotation = annotation, annotation_colors = ann_colors, main = "Example with all the features")
+#' test = matrix(rnorm(200), 20, 10)
+#' test[1:10, seq(1, 10, 2)] = test[1:10, seq(1, 10, 2)] + 3
+#' test[11:20, seq(2, 10, 2)] = test[11:20, seq(2, 10, 2)] + 2
+#' test[15:20, seq(2, 10, 2)] = test[15:20, seq(2, 10, 2)] + 4
+#' colnames(test) = paste("Test", 1:10, sep = "")
+#' rownames(test) = paste("Gene", 1:20, sep = "")
 #' 
-#'	# Specifying clustering from distance matrix
-#'	drows = dist(test, method = "minkowski")
-#'	dcols = dist(t(test), method = "minkowski")
-#'	pheatmap(test, clustering_distance_rows = drows, clustering_distance_cols = dcols)
-#'	
+#' # Draw heatmaps
+#' pheatmap(test)
+#' pheatmap(test, kmeans_k = 2)
+#' pheatmap(test, scale = "row", clustering_distance_rows = "correlation")
+#' pheatmap(test, color = colorRampPalette(c("navy", "white", "firebrick3"))(50))
+#' pheatmap(test, cluster_row = FALSE)
+#' pheatmap(test, legend = FALSE)
+#' pheatmap(test, display_numbers = TRUE)
+#' pheatmap(test, display_numbers = TRUE, number_format = "%.1e")
+#' pheatmap(test, cluster_row = FALSE, legend_breaks = -1:4, legend_labels = c("0", 
+#' "1e-4", "1e-3", "1e-2", "1e-1", "1"))
+#' pheatmap(test, cellwidth = 15, cellheight = 12, main = "Example heatmap")
+#' pheatmap(test, cellwidth = 15, cellheight = 12, fontsize = 8, filename = "test.pdf")
+#' 
+#' 
+#' # Generate column annotations
+#' annotation = data.frame(Var1 = factor(1:10 \%\% 2 == 0, labels = c("Class1", "Class2")), Var2 = 1:10)
+#' annotation$Var1 = factor(annotation$Var1, levels = c("Class1", "Class2", "Class3"))
+#' rownames(annotation) = paste("Test", 1:10, sep = "")
+#' 
+#' pheatmap(test, annotation = annotation)
+#' pheatmap(test, annotation = annotation, annotation_legend = FALSE)
+#' pheatmap(test, annotation = annotation, annotation_legend = FALSE, drop_levels = FALSE)
+#' 
+#' # Specify colors
+#' Var1 = c("navy", "darkgreen")
+#' names(Var1) = c("Class1", "Class2")
+#' Var2 = c("lightgreen", "navy")
+#' 
+#' ann_colors = list(Var1 = Var1, Var2 = Var2)
+#' 
+#' pheatmap(test, annotation = annotation, annotation_colors = ann_colors, main = "Example with all the features")
+#' 
+#' # Specifying clustering from distance matrix
+#' drows = dist(test, method = "minkowski")
+#' dcols = dist(t(test), method = "minkowski")
+#' pheatmap(test, clustering_distance_rows = drows, clustering_distance_cols = dcols)
+#'
 #' @export
 pheatmap = function(mat, color = colorRampPalette(rev(c("#D73027", "#FC8D59", "#FEE090", "#FFFFBF", "#E0F3F8", "#91BFDB", "#4575B4")))(100), kmeans_k = NA, breaks = NA, border_color = "grey60", cellwidth = NA, cellheight = NA, scale = "none", cluster_rows = TRUE, cluster_cols = TRUE, clustering_distance_rows = "euclidean", clustering_distance_cols = "euclidean", clustering_method = "complete",  treeheight_row = ifelse(cluster_rows, 50, 0), treeheight_col = ifelse(cluster_cols, 50, 0), legend = TRUE, legend_breaks = NA, legend_labels = NA, annotation = NA, annotation_colors = NA, annotation_legend = TRUE, drop_levels = TRUE, show_rownames = T, show_colnames = T, main = NA, fontsize = 10, fontsize_row = fontsize, fontsize_col = fontsize, display_numbers = F, number_format = "%.2f", fontsize_number = 0.8 * fontsize, filename = NA, width = NA, height = NA, ...){
 	
